@@ -1,15 +1,16 @@
 
 /*
  *  autogen.c
- *  $Id: autogen.c,v 4.24 2007/08/05 17:09:50 bkorb Exp $
+ *  $Id: autogen.c,v 4.27 2008/01/23 00:36:00 bkorb Exp $
  *
- *  Time-stamp:        "2007-07-22 09:00:32 bkorb"
- *  Last Committed:    $Date: 2007/08/05 17:09:50 $
+ *  Time-stamp:        "2007-12-02 12:06:21 bkorb"
+ *  Last Committed:    $Date: 2008/01/23 00:36:00 $
  *
  *  This is the main routine for autogen.
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -88,11 +89,10 @@ inner_main( int argc, char** argv )
     exit( EXIT_SUCCESS );
 }
 
-
 int
-main( int    argc,
-      char** argv )
+main(int argc, char** argv)
 {
+    optionSaveState(&autogenOptions);
     pfTrace = stderr;
 
     /*
@@ -220,7 +220,7 @@ doneCheck( void )
 #ifdef SHELL_ENABLED
     ag_scm_c_eval_string_from_file_line(
         "(if (> (string-length shell-cleanup) 0)"
-        " (shell shell-cleanup) )", __FILE__, __LINE__ );
+        " (shell shell-cleanup) )", __FILE__, __LINE__ - 1 );
     closeServer();
 #endif
 
@@ -228,7 +228,7 @@ doneCheck( void )
     fflush( stderr );
 
     if (pfTrace != stderr ) {
-        if (* OPT_ARG( TRACE_OUT ) == '|') {
+        if (trace_is_to_pipe) {
             int status;
 
             pclose( pfTrace );
@@ -357,9 +357,9 @@ ag_abend_at( tCC* pzMsg
 #endif
 
     if ((procState >= PROC_STATE_LIB_LOAD) && (pCurTemplate != NULL)) {
-        int line = (pCurMacro == NULL) ? -1 : pCurMacro->lineNo;
+        int l_no = (pCurMacro == NULL) ? -1 : pCurMacro->lineNo;
         fprintf( stderr, "Error in template %s, line %d\n\t",
-                 pCurTemplate->pzTplFile, line );
+                 pCurTemplate->pzTplFile, l_no );
     }
     fputs( pzMsg, stderr );
     pzMsg += strlen( pzMsg );
