@@ -1,14 +1,15 @@
 
 /*
- *  $Id: expOutput.c,v 4.24 2007/07/04 20:51:11 bkorb Exp $
+ *  $Id: expOutput.c,v 4.31 2008/01/23 00:36:01 bkorb Exp $
  *
- *  Time-stamp:        "2007-07-04 11:19:28 bkorb"
- *  Last Committed:    $Date: 2007/07/04 20:51:11 $
+ *  Time-stamp:        "2007-12-05 06:19:49 bkorb"
+ *  Last Committed:    $Date: 2008/01/23 00:36:01 $
  *
  *  This module implements the output file manipulation function
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -42,7 +43,7 @@ static tSuspendName*  pSuspended  = NULL;
 static int            outputDepth = 1;
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
+/* static forward declarations maintained by mk-fwd */
 static void
 addWriteAccess( char* pzFileName );
 /* = = = END-STATIC-FORWARD = = = */
@@ -116,7 +117,8 @@ ag_scm_out_delete( void )
     /*
      *  Delete the current output file
      */
-    fprintf( pfTrace, zSkipMsg, pCurFp->pzOutName );
+    if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
+        fprintf( pfTrace, zSkipMsg, pCurFp->pzOutName );
     outputDepth = 1;
     longjmp( fileAbort, PROBLEM );
     /* NOTREACHED */
@@ -142,7 +144,9 @@ ag_scm_out_move( SCM new_file )
     memcpy( pz, AG_SCM_CHARS( new_file ), sz );
     pz[ sz ] = NUL;
 
-    rename( pCurFp->pzOutName, pz );
+    if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
+        fprintf( pfTrace, "renaming %s to %s\n",  pCurFp->pzOutName, pz);
+    rename(pCurFp->pzOutName, pz);
     if ((pCurFp->flags & FPF_STATIC_NM) == 0)
         AGFREE( (void*)pCurFp->pzOutName );
     AGDUPSTR( pCurFp->pzOutName, pz, "file name" );
@@ -185,6 +189,9 @@ ag_scm_out_pop( SCM ret_contents )
         }
     }
 
+    if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
+        fputs("out-pop\n", pfTrace);
+
     outputDepth--;
     closeOutput( AG_FALSE );
     return res;
@@ -224,6 +231,10 @@ ag_scm_out_suspend( SCM suspName )
 
     pSuspended[ suspendCt-1 ].pzSuspendName = gh_scm2newstr( suspName, NULL );
     pSuspended[ suspendCt-1 ].pOutDesc      = pCurFp;
+    if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
+        fprintf(pfTrace, "suspended output to '%s'\n",
+                pSuspended[ suspendCt-1 ].pzSuspendName);
+
     pCurFp = pCurFp->pPrev;
     outputDepth--;
 
@@ -254,6 +265,8 @@ ag_scm_out_resume( SCM suspName )
             if (ix < --suspendCt)
                 pSuspended[ ix ] = pSuspended[ suspendCt ];
             ++outputDepth;
+            if (OPT_VALUE_TRACE >= TRACE_EXPRESSIONS)
+                fprintf(pfTrace, "resuming output to '%s'\n", pzName);
             return SCM_UNDEFINED;
         }
     }
@@ -265,6 +278,22 @@ ag_scm_out_resume( SCM suspName )
 }
 
 
+/*=gfunc out_emit_suspended
+ *
+ * what:   emit the text of suspended output
+ * exparg: suspName, A name tag of suspended output
+ * doc:
+ *  This function is equivalent to
+ *  @code{(begin (out-resume <name>) (out-pop #t))}
+=*/
+SCM
+ag_scm_out_emit_suspended( SCM suspName )
+{
+    (void)ag_scm_out_resume(suspName);
+    return ag_scm_out_pop(SCM_BOOL_T);
+}
+
+
 /*=gfunc ag_fprintf
  *
  * what:  format to autogen stream
@@ -385,6 +414,8 @@ ag_scm_out_push_add( SCM new_file )
     p->pzOutName = pzNewFile;
     outputDepth++;
     pCurFp       = p;
+    if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
+        fprintf(pfTrace, "appending output to '%s'\n", pzNewFile);
     return SCM_UNDEFINED;
 }
 
@@ -419,6 +450,8 @@ ag_scm_out_push_new( SCM new_file )
         pzNewFile[ sz ] = NUL;
         unlink( pzNewFile );
         addWriteAccess( pzNewFile );
+        if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
+            fprintf(pfTrace, "creating output to '%s'\n", pzNewFile);
         p->pFile = fopen( pzNewFile, "a" FOPEN_BINARY_FLAG "+" );
     }
     else
@@ -526,6 +559,9 @@ ag_scm_out_switch( SCM new_file )
     tbuf.actime  = time( NULL );
     tbuf.modtime = outTime;
     utime( pCurFp->pzOutName, &tbuf );
+    if (OPT_VALUE_TRACE > TRACE_DEBUG_MESSAGE)
+        fprintf(pfTrace, "switching output from %s to '%s'\n",
+                pCurFp->pzOutName, pzNewFile);
     pCurFp->pzOutName = pzNewFile;  /* memory leak */
 
     return SCM_UNDEFINED;
@@ -705,8 +741,9 @@ ag_scm_make_header_guard(SCM name)
         lpz = opz;
         do  {
             *(scan_p++) = '_';
-            while ((! isalnum(*lpz)) && (*lpz != NUL))  lpz++;
-            while (isalnum(*lpz))   *(scan_p++) = toupper(*(lpz++));
+            while ((! IS_ALPHANUMERIC_CHAR(*lpz)) && (*lpz != NUL))  lpz++;
+            while (IS_ALPHANUMERIC_CHAR(*lpz))
+                *(scan_p++) = toupper(*(lpz++));
         } while (*lpz != NUL);
 
         memcpy(scan_p, grd, sizeof(grd));
