@@ -1,33 +1,30 @@
 
 /*
  *  expState.c
- *  $Id: expState.c,v 4.18 2006/12/10 19:41:26 bkorb Exp $
+ *  $Id: expState.c,v 4.26 2008/01/23 00:36:01 bkorb Exp $
  *
- *  Time-stamp:        "2006-12-10 11:04:48 bkorb"
- *  Last Committed:    $Date: 2006/12/10 19:41:26 $
+ *  Time-stamp:        "2007-12-23 12:49:15 bkorb"
+ *  Last Committed:    $Date: 2008/01/23 00:36:01 $
  *
  *  This module implements expression functions that
  *  query and get state information from AutoGen data.
- */
-
-/*
- *  AutoGen copyright 1992-2006 Bruce Korb
  *
- *  AutoGen is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoGen.
+ *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
  *
- *  AutoGen is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- *  See the GNU General Public License for more details.
+ * AutoGen is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with AutoGen.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ * AutoGen is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef SCM_HAVE_T_UINT64
@@ -50,7 +47,7 @@
 #endif
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
+/* static forward declarations maintained by mk-fwd */
 static int
 entry_length( char* pzName );
 
@@ -257,10 +254,10 @@ str2int_ver( char* pz )
     while (--ix >= 0) {
         unsigned int v;
         val <<= VER_UNIT_SHIFT;
-        while (isspace(*pz))  pz++;
+        while (IS_WHITESPACE_CHAR(*pz))  pz++;
 
     next_number:
-        if (! isdigit(*pz)) break;
+        if (! IS_DEC_DIGIT_CHAR(*pz)) break;
         v = (unsigned int)strtoul(pz, &pz, 0) & ((1 << VER_UNIT_SHIFT) - 1);
         if (pz == NULL)
             break;
@@ -282,7 +279,7 @@ str2int_ver( char* pz )
             goto leave_str2int_ver;
 
         case '.':
-            if (! isdigit( *(++pz) ))
+            if (! IS_DEC_DIGIT_CHAR( *(++pz) ))
                 goto leave_str2int_ver;
             break;
         }
@@ -498,6 +495,76 @@ ag_scm_get( SCM agName, SCM altVal )
 }
 
 
+/*=gfunc get_c_name
+ *
+ * what:   get named value, mapped to C name syntax
+ *
+ * exparg: ag-name, name of AutoGen value
+ *
+ * doc:
+ *
+ *  Get the first string value associated with the name.  It will either
+ *  return the associated string value (if the name resolves), the alternate
+ *  value (if one is provided), or else the empty string.  The result is
+ *  passed through "string->c-name!".
+=*/
+SCM
+ag_scm_get_c_name(SCM agName)
+{
+    tDefEntry*  pE;
+    ag_bool     x;
+
+    if (! AG_SCM_STRING_P( agName ))
+         pE = NULL;
+    else pE = findDefEntry( ag_scm2zchars( agName, "ag value" ), &x );
+
+    if ((pE == NULL) || (pE->valType != VALTYP_TEXT))
+        return AG_SCM_STR02SCM(zNil);
+
+    return ag_scm_string_to_c_name_x( AG_SCM_STR02SCM( pE->val.pzText));
+}
+
+
+/*=gfunc get_up_name
+ *
+ * what:   get upper cased named value, mapped to C name syntax
+ *
+ * exparg: ag-name, name of AutoGen value
+ *
+ * doc:
+ *
+ *  Get the first string value associated with the name.  It will either
+ *  return the associated string value (if the name resolves), the alternate
+ *  value (if one is provided), or else the empty string.  The result is
+ *  passed through "string->c-name!" and "string->up-case!".
+=*/
+SCM
+ag_scm_get_up_name(SCM agName)
+{
+    return ag_scm_string_upcase_x( ag_scm_get_c_name( agName));
+}
+
+
+/*=gfunc get_down_name
+ *
+ * what:   get lower cased named value, mapped to C name syntax
+ *
+ * exparg: ag-name, name of AutoGen value
+ *
+ * doc:
+ *
+ *  Get the first string value associated with the name.  It will either
+ *  return the associated string value (if the name resolves), the alternate
+ *  value (if one is provided), or else the empty string.  The result is
+ *  passed through "string->c-name!" and "string->down-case!".
+=*/
+SCM
+ag_scm_get_down_name(SCM agName)
+{
+    return ag_scm_string_downcase_x( ag_scm_get_c_name( agName));
+}
+
+
 /*=gfunc high_lim
  *
  * what:   get highest value index
@@ -641,7 +708,7 @@ ag_scm_tpl_file( SCM full )
     if (AG_SCM_BOOL_P( full ) && SCM_NFALSEP( full )) {
         tSCC* sfx[] = { "tpl", NULL };
         char z[AG_PATH_MAX];
-        if (SUCCESSFUL( findFile( pzTemplFileName, z, sfx )))
+        if (SUCCESSFUL( findFile( pzTemplFileName, z, sfx, NULL )))
             return AG_SCM_STR02SCM( z );
     }
 
