@@ -1,9 +1,9 @@
 
 /*
- *  $Id: funcCase.c,v 4.18 2007/08/05 17:09:51 bkorb Exp $
+ *  $Id: funcCase.c,v 4.23 2008/01/23 00:36:01 bkorb Exp $
  *
- *  Time-stamp:        "2007-07-04 11:25:51 bkorb"
- *  Last Committed:    $Date: 2007/08/05 17:09:51 $
+ *  Time-stamp:        "2007-12-02 15:09:39 bkorb"
+ *  Last Committed:    $Date: 2008/01/23 00:36:01 $
  *
  *  This module implements the CASE text function.
  */
@@ -11,7 +11,8 @@
 
 /*
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -38,7 +39,7 @@
 #  endif
 #endif
 
-#define PTRUP(p) STMTS(if(IS_LOW(*(p)))*(p)=_toupper(*(p));(p)++)
+#define PTRUP(p) STMTS(if(IS_LOW(*(p))) *(p)=_toupper(*(p));(p)++)
 
 tSCC zBadRe[]  = "Invalid regular expression:  error %d (%s):\n%s";
 
@@ -79,10 +80,10 @@ static tpLoadProc apSelectOnly[ FUNC_CT ] = { NULL };
 /* = = = START-STATIC-FORWARD = = = */
 /* static forward declarations maintained by mk-fwd */
 static void
-compile_re( regex_t* pRe, char* pzPat, int flags );
+compile_re(regex_t* pRe, char const * pzPat, int flags);
 
 static void
-upString( char* pz );
+upString(char* pz);
 
 static tSuccess
 Select_Compare( tCC* pzText, tCC* pzMatch );
@@ -136,9 +137,10 @@ mLoad_Select( tTemplate* pT, tMacro* pMac, tCC** ppzScan );
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 static void
-compile_re( regex_t* pRe, char* pzPat, int flags )
+compile_re(regex_t* pRe, char const * pzPat, int flags)
 {
-    int  rerr = regcomp( pRe, pzPat, flags );
+    void * const pat = (void *)pzPat;
+    int  rerr = regcomp(pRe, pat, flags);
     if (rerr != 0) {
         char zEr[ 128 ];
         regerror( rerr, pRe, zEr, sizeof( zEr ));
@@ -149,10 +151,9 @@ compile_re( regex_t* pRe, char* pzPat, int flags )
 
 
 static void
-upString( char* pz )
+upString(char* pz)
 {
-    while (*pz != NUL)
-        PTRUP(pz);
+    while (*pz != NUL) PTRUP(pz);
 }
 
 
@@ -489,8 +490,9 @@ Select_Match( tCC* pzText, tCC* pzMatch )
      *  On the first call for this macro, compile the expression
      */
     if (pCurMacro->funcPrivate == NULL) {
-        regex_t*  pRe = AGALOC( sizeof( *pRe ), "select match re" );
-        compile_re(pRe, (char*)pzMatch, (int)pCurMacro->res);
+        void *    mat = (void *)pzMatch;
+        regex_t*  pRe = AGALOC(sizeof( *pRe ), "select match re");
+        compile_re(pRe, mat, (int)pCurMacro->res);
         pCurMacro->funcPrivate = (void*)pRe;
     }
 
@@ -571,8 +573,9 @@ Select_Match_End( tCC* pzText, tCC* pzMatch )
      *  On the first call for this macro, compile the expression
      */
     if (pCurMacro->funcPrivate == NULL) {
+        void *    mat = (void *)pzMatch;
         regex_t*  pRe = AGALOC( sizeof( *pRe ), "select match end re" );
-        compile_re(pRe, (char*)pzMatch, (int)pCurMacro->res);
+        compile_re(pRe, mat, (int)pCurMacro->res);
         pCurMacro->funcPrivate = (void*)pRe;
     }
 
@@ -663,8 +666,9 @@ Select_Match_Start( tCC* pzText, tCC* pzMatch )
      *  On the first call for this macro, compile the expression
      */
     if (pCurMacro->funcPrivate == NULL) {
+        void *    mat = (void *)pzMatch;
         regex_t*  pRe = AGALOC( sizeof( *pRe ), "select match start re" );
-        compile_re(pRe, (char*)pzMatch, (int)pCurMacro->res);
+        compile_re(pRe, mat, (int)pCurMacro->res);
         pCurMacro->funcPrivate = (void*)pRe;
     }
 
@@ -757,12 +761,14 @@ Select_Match_Full( tCC* pzText, tCC* pzMatch )
      *  On the first call for this macro, compile the expression
      */
     if (pCurMacro->funcPrivate == NULL) {
+        void *    mat = (void *)pzMatch;
         regex_t*  pRe = AGALOC( sizeof( *pRe ), "select match full re" );
+
         if (OPT_VALUE_TRACE > TRACE_EXPRESSIONS) {
             fprintf( pfTrace, "Compiling ``%s'' with bits 0x%lX\n",
                      pzMatch, pCurMacro->res );
         }
-        compile_re(pRe, (char*)pzMatch, (int)pCurMacro->res);
+        compile_re(pRe, mat, (int)pCurMacro->res);
         pCurMacro->funcPrivate = pRe;
     }
 
@@ -994,7 +1000,7 @@ mFunc_Case( tTemplate* pT, tMacro* pMac )
                 fprintf( pfTrace, "CASE string `%s' did not match\n",
                          pzSampleText );
 
-                if (OPT_VALUE_TRACE < TRACE_EVERYTHING)
+                if (OPT_VALUE_TRACE == TRACE_EVERYTHING)
                     fprintf( pfTrace, zFileLine, pCurTemplate->pzTplFile,
                              pMac->lineNo );
             }
@@ -1019,7 +1025,7 @@ mFunc_Case( tTemplate* pT, tMacro* pMac )
                          apzMatchName[ pMac->funcCode & 0x0F ],
                          pT->pzTemplText + pMac->ozText );
 
-                if (OPT_VALUE_TRACE < TRACE_EVERYTHING)
+                if (OPT_VALUE_TRACE == TRACE_EVERYTHING)
                     fprintf( pfTrace, zFileLine, pCurTemplate->pzTplFile,
                              pMac->lineNo );
             }
@@ -1293,8 +1299,10 @@ mLoad_Select( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     *(pzCopy++) = NUL;
     pT->pNext = pzCopy;
 
-    if ((*pzScan == '"') || (*pzScan == '\''))
-        spanQuote( (char*)pzScan );
+    if ((*pzScan == '"') || (*pzScan == '\'')) {
+        void * ptr = (void *)pzScan;
+        spanQuote(ptr);
+    }
 
  selection_done:
     pMac->funcCode = (teFuncType)typ;
