@@ -1,14 +1,15 @@
 
 /*
- *  $Id: funcFor.c,v 4.19 2007/08/05 17:09:51 bkorb Exp $
+ *  $Id: funcFor.c,v 4.24 2008/01/23 00:36:02 bkorb Exp $
  *
- *  Time-stamp:        "2007-07-04 11:26:24 bkorb"
- *  Last Committed:    $Date: 2007/08/05 17:09:51 $
+ *  Time-stamp:        "2007-12-02 15:58:01 bkorb"
+ *  Last Committed:    $Date: 2008/01/23 00:36:02 $
  *
  *  This module implements the FOR text macro.
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoGen copyright (c) 1992-2008 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -506,7 +507,7 @@ load_ForIn( tCC* pzSrc, size_t srcLen, tTemplate* pT, tMacro* pMac )
      */
     pzSrc  += 2;
     srcLen -= 3;
-    while (isspace( *++pzSrc ))  srcLen--;
+    while (IS_WHITESPACE_CHAR(*++pzSrc))  srcLen--;
     if (*pzSrc == NUL)
         AG_ABEND_IN( pT, pMac, "FOR x IN ... has no list" );
 
@@ -538,7 +539,7 @@ load_ForIn( tCC* pzSrc, size_t srcLen, tTemplate* pT, tMacro* pMac )
             /*
              *  Clean up trailing commas
              */
-            while (isspace( *pz ))  pz++;
+            while (IS_WHITESPACE_CHAR(*pz))  pz++;
             if (*pz == ',')
                 pz++;
             break;
@@ -573,7 +574,7 @@ load_ForIn( tCC* pzSrc, size_t srcLen, tTemplate* pT, tMacro* pMac )
         /*
          *  Clean up trailing white space
          */
-        while (isspace( *pz ))  pz++;
+        while (IS_WHITESPACE_CHAR(*pz))  pz++;
 
         /*
          *  IF there is a previous entry, link its twin to this one.
@@ -689,6 +690,13 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
     tDefEntry*  pDef;
     int         loopCt;
 
+    /*
+     *  "funcPrivate" is used by the "FOR x IN ..." variation of the macro.
+     *  When parsed, a chain of text definitions are hung off of "funcPrivate".
+     *  "doForEach()" will then chase through the linked list of text
+     *  values.  This winds up being identical to [+ FOR var +] where
+     *  a list of "var" values has been set.
+     */
     if (pMac->funcPrivate != NULL)
         pDef = pMac->funcPrivate;
     else {
@@ -698,7 +706,7 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
                 fprintf( pfTrace, "FOR loop skipped - no definition for `%s'\n",
                          pT->pzTemplText + pMac->ozName );
 
-                if (OPT_VALUE_TRACE < TRACE_EVERYTHING)
+                if (OPT_VALUE_TRACE == TRACE_EVERYTHING)
                     fprintf( pfTrace, zFileLine, pT->pzTplFile, pMac->lineNo );
             }
 
@@ -706,6 +714,9 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
         }
     }
 
+    /*
+     *  Push the current FOR context onto a stack.
+     */
     if (++(forInfo.fi_depth) > forInfo.fi_alloc) {
         forInfo.fi_alloc += 5;
         if (forInfo.fi_data == NULL)
@@ -727,6 +738,9 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
                  pT->pzTemplText + pMac->ozName, pT->pzTplFile,
                  pMac->lineNo );
 
+    /*
+     *  Check for a FOR iterating based on scheme macros
+     */
     if (pT->pzTemplText[ pMac->ozText ] == '(') {
         pFS->for_from  = \
         pFS->for_to    = 0x7BAD0BAD;
@@ -737,6 +751,9 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
         loopCt = doForByStep( pT, pMac, pDef );
     }
     else {
+        /*
+         *  The FOR iterates over a list of definitions
+         */
         pFS->for_pzSep = pT->pzTemplText + pMac->ozText;
         loopCt = doForEach( pT, pMac, pDef );
     }
@@ -747,7 +764,7 @@ mFunc_For( tTemplate* pT, tMacro* pMac )
         fprintf( pfTrace, "FOR %s repeated %d times\n",
                  pT->pzTemplText + pMac->ozName, loopCt );
 
-        if (OPT_VALUE_TRACE < TRACE_EVERYTHING)
+        if (OPT_VALUE_TRACE == TRACE_EVERYTHING)
             fprintf( pfTrace, zFileLine, pT->pzTplFile, pMac->lineNo );
     }
 
@@ -794,11 +811,11 @@ mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     pMac->ozName = pT->pNext - pT->pzTemplText;
     if (*pzSrc == '.') {
         *(pzCopy++) = *(pzSrc++);
-        if (! ISNAMECHAR( *pzSrc ))
+        if (! IS_VAR_FIRST_CHAR(*pzSrc))
             pzCopy--; /* force an error */
     }
 
-    while (ISNAMECHAR( *pzSrc )) *(pzCopy++) = *(pzSrc++);
+    while (IS_VALUE_NAME_CHAR(*pzSrc)) *(pzCopy++) = *(pzSrc++);
     *(pzCopy++) = NUL;
 
     if (pT->pzTemplText[ pMac->ozName ] == NUL)
@@ -807,7 +824,7 @@ mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
     /*
      *  Skip space to the start of the text following the iterator name
      */
-    while (isspace( *pzSrc )) pzSrc++;
+    while (IS_WHITESPACE_CHAR(*pzSrc)) pzSrc++;
     srcLen -= pzSrc - (char*)pMac->ozText;
 
     /* * * * *
@@ -823,7 +840,7 @@ mLoad_For( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
      *  FOR foo IN ...  -> no text, but we create an array of text values
      */
     else if (   (strneqvcmp( pzSrc, "in", 2 ) == 0)
-             && isspace( pzSrc[2] )) {
+             && IS_WHITESPACE_CHAR(pzSrc[2])) {
         load_ForIn( pzSrc, srcLen, pT, pMac );
     }
 
