@@ -1,7 +1,7 @@
 
 /*
- *  $Id: putshell.c,v 4.20 2007/07/04 21:36:38 bkorb Exp $
- * Time-stamp:      "2007-07-04 11:34:33 bkorb"
+ *  $Id: putshell.c,v 4.23 2008/01/23 00:36:05 bkorb Exp $
+ * Time-stamp:      "2007-11-12 20:39:57 bkorb"
  *
  *  This module will interpret the options set in the tOptions
  *  structure and print them to standard out in a fashion that
@@ -9,7 +9,8 @@
  *
  *  This file is part of AutoOpts, a companion to AutoGen.
  *  AutoOpts is free software.
- *  AutoOpts is copyright (c) 1992-2007 by Bruce Korb - all rights reserved
+ *  AutoOpts is copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoOpts is copyright (c) 1992-2008 by Bruce Korb - all rights reserved
  *
  *  AutoOpts is available under any one of two licenses.  The license
  *  in use must be one of these two and the choice is under the control
@@ -29,7 +30,7 @@
  */
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
+/* static forward declarations maintained by mk-fwd */
 static void
 putQuotedStr( tCC* pzStr );
 /* = = = END-STATIC-FORWARD = = = */
@@ -167,14 +168,14 @@ optionPutShell( tOptions* pOpts )
             pz = pOD->optArg.argString + 7;
             while (*pz != NUL) {
                 printf( "typeset -x -i %s_", pOD->pz_NAME );
-                pz += strspn( pz, " +\t\n\f" );
+                while (IS_PLUS_N_SPACE_CHAR(*pz))  pz++;
+
                 for (;;) {
                     int ch = *(pz++);
-                         if (islower( ch ))  fputc( toupper( ch ), stdout );
-                    else if (isalnum( ch ))  fputc( ch, stdout );
-                    else if (isspace( ch )
-                          || (ch == '+'))    goto name_done;
-                    else if (ch == NUL)      { pz--; goto name_done; }
+                         if (IS_LOWER_CASE_CHAR(ch))   fputc(toupper(ch), stdout);
+                    else if (IS_UPPER_CASE_CHAR(ch))   fputc(ch, stdout);
+                    else if (IS_PLUS_N_SPACE_CHAR(ch)) goto name_done;
+                    else if (ch == NUL)           { pz--; goto name_done; }
                     else fputc( '_', stdout );
                 } name_done:;
                 printf( "=%1$lu # 0x%1$lX\n", (unsigned long)val );
