@@ -1,60 +1,38 @@
 
 /*
- *  save.c  $Id: save.c,v 4.11 2005/06/07 22:26:44 bkorb Exp $
- * Time-stamp:      "2005-02-20 13:49:46 bkorb"
+ *  save.c  $Id: save.c,v 4.22 2008/01/23 00:36:05 bkorb Exp $
+ * Time-stamp:      "2007-09-08 13:04:32 bkorb"
  *
  *  This module's routines will take the currently set options and
  *  store them into an ".rc" file for re-interpretation the next
  *  time the invoking program is run.
- */
-
-/*
- *  Automated Options copyright 1992-2005 Bruce Korb
  *
- *  Automated Options is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoOpts, a companion to AutoGen.
+ *  AutoOpts is free software.
+ *  AutoOpts is copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoOpts is copyright (c) 1992-2008 by Bruce Korb - all rights reserved
  *
- *  Automated Options is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  AutoOpts is available under any one of two licenses.  The license
+ *  in use must be one of these two and the choice is under the control
+ *  of the user of the license.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with Automated Options.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ *   The GNU Lesser General Public License, version 3 or later
+ *      See the files "COPYING.lgplv3" and "COPYING.gplv3"
  *
- * As a special exception, Bruce Korb gives permission for additional
- * uses of the text contained in his release of AutoOpts.
+ *   The Modified Berkeley Software Distribution License
+ *      See the file "COPYING.mbsd"
  *
- * The exception is that, if you link the AutoOpts library with other
- * files to produce an executable, this does not by itself cause the
- * resulting executable to be covered by the GNU General Public License.
- * Your use of that executable is in no way restricted on account of
- * linking the AutoOpts library code into it.
+ *  These files have the following md5sums:
  *
- * This exception does not however invalidate any other reasons why
- * the executable file might be covered by the GNU General Public License.
- *
- * This exception applies only to the code released by Bruce Korb under
- * the name AutoOpts.  If you copy code from other sources under the
- * General Public License into a copy of AutoOpts, as the General Public
- * License permits, the exception does not apply to the code that you add
- * in this way.  To avoid misleading anyone as to the status of such
- * modified files, you must delete this exception notice from them.
- *
- * If you write modifications of your own for AutoOpts, it is your choice
- * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.
+ *  239588c55c22c60ffe159946a760a33e pkg/libopts/COPYING.gplv3
+ *  fa82ca978890795162346e661b47161a pkg/libopts/COPYING.lgplv3
+ *  66a5cedaf62c4b2637025f049f9b826f pkg/libopts/COPYING.mbsd
  */
 
 tSCC  zWarn[] = "%s WARNING:  cannot save options - ";
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
+/* static forward declarations maintained by mk-fwd */
 static tCC*
 findDirName( tOptions* pOpts, int* p_free );
 
@@ -63,8 +41,8 @@ findFileName( tOptions* pOpts, int* p_free_name );
 
 static void
 printEntry(
-    FILE*      fp,
-    tOptDesc*  p,
+    FILE *     fp,
+    tOptDesc * p,
     tCC*       pzLA );
 /* = = = END-STATIC-FORWARD = = = */
 
@@ -76,7 +54,7 @@ findDirName( tOptions* pOpts, int* p_free )
     if (pOpts->specOptIdx.save_opts == 0)
         return NULL;
 
-    pzDir = pOpts->pOptDesc[ pOpts->specOptIdx.save_opts ].pzLastArg;
+    pzDir = pOpts->pOptDesc[ pOpts->specOptIdx.save_opts ].optArg.argString;
     if ((pzDir != NULL) && (*pzDir != NUL))
         return pzDir;
 
@@ -100,7 +78,7 @@ findDirName( tOptions* pOpts, int* p_free )
         return pzDir;
 
     {
-        tCC*  pzEndDir = strchr( ++pzDir, '/' );
+        tCC*  pzEndDir = strchr( ++pzDir, DIRCH );
         char* pzFileName;
         char* pzEnv;
 
@@ -108,7 +86,7 @@ findDirName( tOptions* pOpts, int* p_free )
             char z[ AO_NAME_SIZE ];
             if ((pzEndDir - pzDir) > AO_NAME_LIMIT )
                 return NULL;
-            strncpy( z, pzDir, (pzEndDir - pzDir) );
+            strncpy( z, pzDir, (size_t)(pzEndDir - pzDir) );
             z[ (pzEndDir - pzDir) ] = NUL;
             pzEnv = getenv( z );
         } else {
@@ -170,19 +148,19 @@ findFileName( tOptions* pOpts, int* p_free_name )
          *  path to a file name that has not been created yet.
          */
         if (errno == ENOENT) {
-            char z[MAXPATHLEN];
+            char z[AG_PATH_MAX];
 
             /*
              *  Strip off the last component, stat the remaining string and
              *  that string must name a directory
              */
-            char* pzDirCh = strrchr( pzDir, '/' );
+            char* pzDirCh = strrchr( pzDir, DIRCH );
             if (pzDirCh == NULL) {
                 stBuf.st_mode = S_IFREG;
                 continue;  /* bail out of error condition */
             }
 
-            strncpy( z, pzDir, pzDirCh - pzDir );
+            strncpy( z, pzDir, (size_t)(pzDirCh - pzDir));
             z[ pzDirCh - pzDir ] = NUL;
 
             if (  (stat( z, &stBuf ) == 0)
@@ -270,22 +248,31 @@ findFileName( tOptions* pOpts, int* p_free_name )
 
 static void
 printEntry(
-    FILE*      fp,
-    tOptDesc*  p,
+    FILE *     fp,
+    tOptDesc * p,
     tCC*       pzLA )
 {
     /*
-     *  There is an argument.  Pad the name so values line up
+     *  There is an argument.  Pad the name so values line up.
+     *  Not disabled *OR* this got equivalenced to another opt,
+     *  then use current option name.
+     *  Otherwise, there must be a disablement name.
      */
-    fprintf( fp, "%-18s",
-             (DISABLED_OPT( p )) ? p->pz_DisableName : p->pz_Name );
+    {
+        char const * pz;
+        if (! DISABLED_OPT(p) || (p->optEquivIndex != NO_EQUIVALENT))
+            pz = p->pz_Name;
+        else
+            pz = p->pz_DisableName;
 
+        fprintf(fp, "%-18s", pz);
+    }
     /*
      *  IF the option is numeric only,
      *  THEN the char pointer is really the number
      */
     if (OPTST_GET_ARGTYPE(p->fOptState) == OPARG_TYPE_NUMERIC)
-        fprintf( fp, "  %d\n", (t_word)pzLA );
+        fprintf( fp, "  %d\n", (int)(t_word)pzLA );
 
     /*
      *  OTHERWISE, FOR each line of the value text, ...
@@ -308,7 +295,7 @@ printEntry(
             /*
              *  Print the continuation and the text from the current line
              */
-            fwrite( pzLA, pzNl - pzLA, 1, fp );
+            (void)fwrite( pzLA, (size_t)(pzNl - pzLA), (size_t)1, fp );
             pzLA = pzNl+1; /* advance the Last Arg pointer */
             fputs( "\\\n", fp );
         }
@@ -370,7 +357,7 @@ optionSaveFile( tOptions* pOpts )
     }
 
     {
-        const char*  pz = pOpts->pzUsageTitle;
+        char const*  pz = pOpts->pzUsageTitle;
         fputs( "#  ", fp );
         do { fputc( *pz, fp ); } while (*(pz++) != '\n');
     }
@@ -413,7 +400,7 @@ optionSaveFile( tOptions* pOpts )
             continue;
 
         if (  (pOD->optEquivIndex != NO_EQUIVALENT)
-              && (pOD->optEquivIndex != pOD->optIndex))
+           && (pOD->optEquivIndex != pOD->optIndex))
             continue;
 
         /*
@@ -428,8 +415,17 @@ optionSaveFile( tOptions* pOpts )
          *  THEN just print the name and continue
          */
         if (OPTST_GET_ARGTYPE(pOD->fOptState) == OPARG_TYPE_NONE) {
-            fprintf( fp, "%s\n",
-                     (DISABLED_OPT( p )) ? p->pz_DisableName : p->pz_Name );
+            char const * pznm =
+                (DISABLED_OPT( p )) ? p->pz_DisableName : p->pz_Name;
+            /*
+             *  If the option was disabled and the disablement name is NULL,
+             *  then the disablement was caused by aliasing.
+             *  Use the name as the string to emit.
+             */
+            if (pznm == NULL)
+                pznm = p->pz_Name;
+
+            fprintf(fp, "%s\n", pznm);
             continue;
         }
 
@@ -437,7 +433,7 @@ optionSaveFile( tOptions* pOpts )
         switch (arg_state) {
         case 0:
         case OPARG_TYPE_NUMERIC:
-            printEntry( fp, p, p->pzLastArg );
+            printEntry( fp, p, (void*)(p->optArg.argInt));
             break;
 
         case OPARG_TYPE_STRING:
@@ -455,31 +451,36 @@ optionSaveFile( tOptions* pOpts )
                 while (uct-- > 0)
                     printEntry( fp, p, *(ppz++) );
             } else {
-                printEntry( fp, p, p->pzLastArg );
+                printEntry( fp, p, p->optArg.argString );
             }
             break;
 
         case OPARG_TYPE_ENUMERATION:
         case OPARG_TYPE_MEMBERSHIP:
         {
-            tCC* val = p->pzLastArg;
+            uintptr_t val = p->optArg.argEnum;
             /*
              *  This is a magic incantation that will convert the
              *  bit flag values back into a string suitable for printing.
              */
             (*(p->pOptProc))( (tOptions*)2UL, p );
-            printEntry( fp, p, p->pzLastArg );
-            if ((p->pzLastArg != NULL) && (arg_state != OPARG_TYPE_ENUMERATION))
+            printEntry( fp, p, (void*)(p->optArg.argString));
+
+            if (  (p->optArg.argString != NULL)
+               && (arg_state != OPARG_TYPE_ENUMERATION)) {
                 /*
-                 *  bit flag and enumeration strings get allocated
+                 *  set membership strings get allocated
                  */
-                AGFREE( (void*)p->pzLastArg );
-            p->pzLastArg = val;
+                AGFREE( (void*)p->optArg.argString );
+                p->fOptState &= ~OPTST_ALLOC_ARG;
+            }
+
+            p->optArg.argEnum = val;
             break;
         }
 
         case OPARG_TYPE_BOOLEAN:
-            printEntry( fp, p, (p->pzLastArg != 0) ? "true" : "false" );
+            printEntry( fp, p, p->optArg.argBool ? "true" : "false" );
             break;
 
         default:
@@ -493,7 +494,6 @@ optionSaveFile( tOptions* pOpts )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of autoopts/save.c */
