@@ -1,7 +1,7 @@
 
 /*
- *  $Id: streqvcmp.c,v 4.7 2006/07/27 02:59:08 bkorb Exp $
- * Time-stamp:      "2006-07-26 18:25:53 bkorb"
+ *  $Id: streqvcmp.c,v 4.13 2008/01/23 00:36:05 bkorb Exp $
+ * Time-stamp:      "2007-07-04 11:35:12 bkorb"
  *
  *  String Equivalence Comparison
  *
@@ -9,52 +9,28 @@
  *  character before comparison.  In processing long option names,
  *  the characters "-", "_" and "^" all need to be equivalent
  *  (because they are treated so by different development environments).
- */
-
-/*
- *  Automated Options copyright 1992-2006 Bruce Korb
  *
- *  Automated Options is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoOpts, a companion to AutoGen.
+ *  AutoOpts is free software.
+ *  AutoOpts is copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoOpts is copyright (c) 1992-2008 by Bruce Korb - all rights reserved
  *
- *  Automated Options is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  AutoOpts is available under any one of two licenses.  The license
+ *  in use must be one of these two and the choice is under the control
+ *  of the user of the license.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with Automated Options.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ *   The GNU Lesser General Public License, version 3 or later
+ *      See the files "COPYING.lgplv3" and "COPYING.gplv3"
  *
- * As a special exception, Bruce Korb gives permission for additional
- * uses of the text contained in his release of AutoOpts.
+ *   The Modified Berkeley Software Distribution License
+ *      See the file "COPYING.mbsd"
  *
- * The exception is that, if you link the AutoOpts library with other
- * files to produce an executable, this does not by itself cause the
- * resulting executable to be covered by the GNU General Public License.
- * Your use of that executable is in no way restricted on account of
- * linking the AutoOpts library code into it.
+ *  These files have the following md5sums:
  *
- * This exception does not however invalidate any other reasons why
- * the executable file might be covered by the GNU General Public License.
+ *  239588c55c22c60ffe159946a760a33e pkg/libopts/COPYING.gplv3
+ *  fa82ca978890795162346e661b47161a pkg/libopts/COPYING.lgplv3
+ *  66a5cedaf62c4b2637025f049f9b826f pkg/libopts/COPYING.mbsd
  *
- * This exception applies only to the code released by Bruce Korb under
- * the name AutoOpts.  If you copy code from other sources under the
- * General Public License into a copy of AutoOpts, as the General Public
- * License permits, the exception does not apply to the code that you add
- * in this way.  To avoid misleading anyone as to the status of such
- * modified files, you must delete this exception notice from them.
- *
- * If you write modifications of your own for AutoOpts, it is your choice
- * whether to permit this exception to apply to your modifications.
- * If you do not wish that, delete this exception notice.
- */
-
-/*
  * This array is designed for mapping upper and lower case letter
  * together for a case independent comparison.  The mappings are
  * based upon ascii character sequences.
@@ -103,8 +79,8 @@ static unsigned char charmap[] = {
  *
  * what: compare two strings with an equivalence mapping
  *
- * arg:  + const char* + str1 + first string +
- * arg:  + const char* + str2 + second string +
+ * arg:  + char const* + str1 + first string +
+ * arg:  + char const* + str2 + second string +
  * arg:  + int         + ct   + compare length +
  *
  * ret_type:  int
@@ -144,8 +120,8 @@ strneqvcmp( tCC* s1, tCC* s2, int ct )
  *
  * what: compare two strings with an equivalence mapping
  *
- * arg:  + const char* + str1 + first string +
- * arg:  + const char* + str2 + second string +
+ * arg:  + char const* + str1 + first string +
+ * arg:  + char const* + str2 + second string +
  *
  * ret_type:  int
  * ret_desc:  the difference between two differing characters
@@ -234,7 +210,7 @@ streqvmap( char From, char To, int ct )
  *
  * what: map a list of characters to the same value
  *
- * arg:  + const char* + ch_list + characters to equivalence +
+ * arg:  + char const* + ch_list + characters to equivalence +
  *
  * doc:
  *
@@ -246,7 +222,7 @@ streqvmap( char From, char To, int ct )
  * err:  none.
 =*/
 void
-strequate( const char* s )
+strequate( char const* s )
 {
     if ((s != NULL) && (*s != NUL)) {
         unsigned char equiv = (unsigned)*s;
@@ -261,7 +237,7 @@ strequate( const char* s )
  * what: convert a string into its mapped-to value
  *
  * arg:  + char*       + dest + output string +
- * arg:  + const char* + src  + input string +
+ * arg:  + char const* + src  + input string +
  *
  * doc:
  *
@@ -273,7 +249,7 @@ strequate( const char* s )
  * err:  none.
 =*/
 void
-strtransform( char* d, const char* s )
+strtransform( char* d, char const* s )
 {
     do  {
         *(d++) = (char)charmap[ (unsigned)*s ];
@@ -284,7 +260,6 @@ strtransform( char* d, const char* s )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of autoopts/streqvcmp.c */
